*******************
Expect Library
*******************

The library that is used for output validation.

.. py:function:: is_not_none(...)

  Validates whether the argument is None or not.

.. py:function:: is_not_empty_list(...)

  Validates whether the list type argument is not empty.

.. py:function:: is_not_empty_dict(...)

  Validates whether the dict type argument is not empty.

.. py:function:: is_not_empty_str(...)

  Validates whether the str type argument is not empty.

.. py:function:: is_pe(...)

  Validates whether the argument is 'application/x-dosexec' or not.
